Received: from malur.postgresql.org ([217.196.149.56]) by arkaria.postgresql.org with esmtps (TLS1.3:ECDHE_RSA_AES_256_GCM_SHA384:256) (Exim 4.92) (envelope-from ) id 1mfZU3-0000zS-PN for pgsql-bugs@arkaria.postgresql.org; Wed, 27 Oct 2021 03:20:11 +0000 Received: from localhost ([127.0.0.1] helo=malur.postgresql.org) by malur.postgresql.org with esmtp (Exim 4.92) (envelope-from ) id 1mfZU2-0008BG-JN for pgsql-bugs@arkaria.postgresql.org; Wed, 27 Oct 2021 03:20:10 +0000 Received: from makus.postgresql.org ([2001:4800:3e1:1::229]) by malur.postgresql.org with esmtps (TLS1.3:ECDHE_RSA_AES_256_GCM_SHA384:256) (Exim 4.92) (envelope-from ) id 1mfZU2-00089Y-Bk for pgsql-bugs@lists.postgresql.org; Wed, 27 Oct 2021 03:20:10 +0000 Received: from sss.pgh.pa.us ([66.207.139.130]) by makus.postgresql.org with esmtps (TLS1.3:ECDHE_RSA_AES_256_GCM_SHA384:256) (Exim 4.92) (envelope-from ) id 1mfZU0-0001LQ-A8 for pgsql-bugs@lists.postgresql.org; Wed, 27 Oct 2021 03:20:09 +0000 Received: from sss1.sss.pgh.pa.us (localhost [127.0.0.1]) by sss.pgh.pa.us (8.15.2/8.15.2) with ESMTP id 19R3K10x197248; Tue, 26 Oct 2021 23:20:01 -0400 From: Tom Lane To: Noah Misch cc: Andrey Borodin , PostgreSQL mailing lists , Michael Paquier , Peter Geoghegan , Andres Freund Subject: Re: conchuela timeouts since 2021-10-09 system upgrade In-reply-to: <20211027030144.GA152505@rfd.leadboat.com> References: <64835CF9-D9AA-49BF-A685-01C23B1023C1@yandex-team.ru> <20211024161942.GB3945842@rfd.leadboat.com> <640FA6DC-A998-4499-B3B4-2773685B8C56@yandex-team.ru> <3792312.1635119599@sss.pgh.pa.us> <4170532.1635195582@sss.pgh.pa.us> <20211026015157.GA113335@rfd.leadboat.com> <52098.1635228234@sss.pgh.pa.us> <20211026134500.GA128912@rfd.leadboat.com> <139687.1635277318@sss.pgh.pa.us> <20211027030144.GA152505@rfd.leadboat.com> Comments: In-reply-to Noah Misch message dated "Tue, 26 Oct 2021 20:01:44 -0700" MIME-Version: 1.0 Content-Type: text/plain; charset="us-ascii" Content-ID: <197246.1635304801.1@sss.pgh.pa.us> Content-Transfer-Encoding: quoted-printable Date: Tue, 26 Oct 2021 23:20:01 -0400 Message-ID: <197247.1635304801@sss.pgh.pa.us> List-Id: List-Help: List-Subscribe: List-Post: List-Owner: List-Archive: Archived-At: Precedence: bulk Noah Misch writes: > On Tue, Oct 26, 2021 at 03:41:58PM -0400, Tom Lane wrote: >> Now the problem with this is it will only work back to v12, because >> pgbench lacks the necessary features before that. However, I think >> it's worth doing it like this in versions where we can do so, because >> of the load-balancing aspect: this won't waste cycles running CICs >> after the inserts have stopped, nor vice versa. > I tried it out with the fix removed (git checkout fdd965d; git checkout = HEAD^ > src/include src/backend; git apply CIC-test-with-one-pgbench.patch). > Sensitivity (~25%) and runtime (~900ms) were in the same ballpark. Stil= l, > even if it doesn't buy back notable cycles, the test code seems easier t= o read > and understand with your change. The point wasn't to reduce the runtime: it was to get more useful test iterations in the same runtime. A test iteration that runs CIC while there are no concurrent inserts isn't providing any useful coverage. It's possible that with this patch, we could dial it back to less than 1000 (200x5) total transactions and still get the same effective number of test iterations as we have in HEAD. I didn't really look into that. I did notice that even on a much faster machine than prairiedog, HEAD wastes at least three-quarters of the CIC iterations. regards, tom lane